@@ -4,22 +4,35 @@ from pydantic import BaseModel, validator
 from typing import List, Optional, Tuple, Any
 
 
+class Input(BaseModel):
+    dir: Optional[str]
+    file_name: Optional[str]
+    matplot: bool = True
+
+class latexOuput(BaseModel):
+    header: Optional[str] 
+class htmlOutput(BaseModel):
+    css: str = "bootstrap"
+
+class Output(BaseModel):
+    fig_dir: str = "figures"
+    format: Optional[str]
+    file_name: Optional[str]
+    dir: Optional[str]
+    latex: Optional[latexOuput]
+    html: Optional[htmlOutput]
+
 
 class GlobalOption(BaseModel):
     title: str
     author: Optional[str]
     date: Optional[str]
-    input_file_dir: Optional[str]
-    input_file_name: Optional[str]
-    matplot: bool = True
     kernal: str = "python3"
     log_level: str = "debug"
-    fig_dir: str = "figures"
-    css: str = "bootstrap"
-    output_format: Optional[str]
-    output_file_name: Optional[str]
-    output_file_dir: Optional[str]
-    
+    cache: Optional[bool] = False
+    output: Output
+    input: Input
+
     @validator('log_level')
     def fix_option_for_log(cls, v:str):
         if v.lower() not in ('notset', "debug", 'info', 'warning', 'error', 'critical'):
@@ -40,6 +53,7 @@ class ChunkOption(BaseModel):
     fig_position: Optional[str] = "htpb"
     fig_env: Optional[str]
     fig_width: Optional[str]
+    con_string: Optional[str] = "zen_con"
 
 BOOLENCHUNCKOPTIONS = ['run', 'echo','render', 'fig']
 
@@ -86,6 +100,7 @@ class OrganizedChuckType(enum.Enum):
     Markdown = "markdown"
     Code = "code"
     Result = "se_data"
-    Error = "e_data"
+    Table = "e_data"
+    HTML = "html_data"
     Plot = "plot"
             
\ No newline at end of file
