@@ -1,3 +1,4 @@
+from zen_knit.formattor.base_formatter import BaseFormatter
 from zen_knit.formattor.html_formatter import HTMLFormatter
 from zen_knit.formattor.markdown_formtter import MarkDownFormatter
 from zen_knit.formattor.tex_formatter import TexFormatter
@@ -11,5 +12,5 @@ my_formatter = {"pdf": TexFormatter,
             "markdown":MarkDownFormatter}
 
 
-def get_formatter(output):
+def get_formatter(output) -> BaseFormatter:
     return my_formatter[output]
\ No newline at end of file
